@@ -66,9 +66,9 @@ class ref_frame:
         if not(x_list is None):
             for i in range(len(frames)):
                 cur_frame = frames[i]
-                cur_x = x_list[i]/self.scale
-                cur_y = y_list[i]/self.scale
-                cur_z = z_list[i]/self.scale
+                cur_x = x_list[i]*self.scale
+                cur_y = y_list[i]*self.scale
+                cur_z = z_list[i]*self.scale
             
                 self.ob.location = (cur_x, cur_y, cur_z)
             
@@ -102,8 +102,8 @@ class dyn_obj:
     def apply_animation(self, x_list, y_list, z_list, quat_list):
         
 
-        self.pa_axes.dynamic_6DOF(quat_list, None, None, None, self.frames)
-        self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list, self.frames)
+        self.pa_axes.dynamic_6DOF(quat_list, None, None, None)
+        self.non_rot.dynamic_6DOF(None, x_list, y_list, z_list)
 
     def apply_streamline(self, staticity, int_x, int_y, int_z, thickness):
         name = self.name+'_streamline'
@@ -111,9 +111,9 @@ class dyn_obj:
         
         int_size = len(int_x)
         int_coords = np.zeros((int_size, 3))
-        int_coords[:, 0] = int_x/self.scale
-        int_coords[:, 1] = int_y/self.scale
-        int_coords[:, 2] = int_z/self.scale
+        int_coords[:, 0] = int_x*self.scale
+        int_coords[:, 1] = int_y*self.scale
+        int_coords[:, 2] = int_z*self.scale
 
         int_curve = bpy.data.curves.new(name, type='CURVE')
         int_curve.dimensions = '3D'
